#!/usr/bin/env python

#-------------------------------------------------------------------
# Objectives
#-------------------------------------------------------------------
# This file describes a configuration with 28 PFTs that correspond 
# to the 13 MTCs, 13 tree species and 2 additional agricultural 
# PFTs without age classes. This configuration is suitable for 
# parameterizing the model as it uses all available parameters.
# The set-up is ideal in combination with impose_veg = y. If
# impose_veg = n adjusted PFT maps need to be used. 
#
# WARNING: the order of the PFTs should match the PFT definition of
# the land cover, forest management, litter raking and species maps
#
# CODING GUIDELINE: variable names written in capitals are variables
# that will end up in the run.defs


#-------------------------------------------------------------------
# Configure the vegetation. 
#-------------------------------------------------------------------
NAGEC = 1
header = ['domain', 'mtc', 'pft', 'species, genus or biome', 'pft_to_mtc', 'has_agec'] 
config = [\
  ['Global', 'BareSoil', 'SoilBare', 'Global', 1, 'n'],
  ['Global', 'TropicalBroadLeavedEvergreen', 'BroadLeavedEvergreen',  'Tropical', 2, 'n'], 
  ['Global', 'TropicalBroadLeavedRaingreen', 'BroadLeavedRaingreen',  'Tropical', 3, 'n'], 
  ['Global', 'TemperateNeedleleafEvergreen', 'NeedleleafEvergreen', 'Temperate', 4, 'n'], 
  ['Europe', 'TemperateNeedleleafEvergreen', 'PinusSylvestris', 'Temperate', 4, 'n'],
  ['Europe', 'TemperateNeedleleafEvergreen', 'PinusPinaster', 'Temperate', 4, 'n'],
  ['Europe', 'TemperateNeedleleafEvergreen', 'PiceaSp', 'Temperate', 4, 'n'],
  ['Europe', 'TemperateNeedleleafEvergreen', 'Residual', 'Temperate', 4, 'n'],
  ['Global', 'TemperateBroadLeavedEvergreen', 'BroadLeavedEvergreen', 'Temperate', 5, 'n'],
  ['Europe', 'TemperateBroadLeavedEvergreen', 'QuercusIlexSuber', 'Temperate', 5, 'n'],
  ['Global', 'TemperateBroadLeavedSummergreen', 'BroadLeavedSummergreen', 'Temperate', 6, 'n'],
  ['Europe', 'TemperateBroadLeavedSummergreen', 'BetulaSp', 'Temperate', 6, 'n'],
  ['Europe', 'TemperateBroadLeavedSummergreen', 'FagusSylvatica', 'Temperate', 6, 'n'],
  ['Europe', 'TemperateBroadLeavedSummergreen', 'QuercusRoburPetraea', 'Temperate', 6, 'n'],
  ['Europe', 'TemperateBroadLeavedSummergreen', 'PopulusSp', 'Temperate', 6, 'n'],
  ['Europe', 'TemperateBroadLeavedSummergreen', 'Residual', 'Temperate', 6, 'n'],
  ['Global', 'BorealNeedleleafEvergreen', 'NeedleleafEvergreen', 'Boreal', 7, 'n'],
  ['Europe', 'BorealNeedleleafEvergreen', 'PinusSylvestris', 'Boreal', 7, 'n'],
  ['Europe', 'BorealNeedleleafEvergreen', 'PiceaSp', 'Boreal', 7, 'n'], 
  ['Global', 'BorealBroadLeavedSummergreen', 'BroadLeavedSummergreen', 'Boreal', 8, 'n'],
  ['Europe', 'BorealBroadLeavedSummergreen', 'BetulaSp', 'Boreal', 8, 'n'],
  ['Global', 'BorealNeedleleafSummergreen', 'LarixSp', 'Boreal', 9, 'n'],
  ['Global', 'C3Grass', 'C3Grass', 'Temperate', 10, 'n'],
  ['Global', 'C3Grass', 'C3Grass', 'Boreal', 10, 'n'],
  ['Global', 'C4Grass', 'C4Grass', 'Temperate',11, 'n'],
  ['Global', 'C3Agriculture', 'C3Agriculture', 'Temperate', 12, 'n'],
  ['Global', 'C3Agriculture', 'C3Agriculture', 'Boreal', 12, 'n'],
  ['Global', 'C4Agriculture', 'C4Agriculture', 'Temperate', 13, 'n']]  

